%define privoxyconf %{_sysconfdir}/%{name}

%define reltype stable

Summary:	Privacy enhancing HTTP proxy
Name:		privoxy
Version:	4.0.0
Release:	%mkrel 1
License:	GPLv2+
Group:		Networking/Other
URL:		https://www.privoxy.org/
Source0:	https://sourceforge.net/projects/ijbswa/files/Sources/%{version}%20%28stable%29/%{name}-%{version}-%{reltype}-src.tar.gz
Source1:	https://sourceforge.net/projects/ijbswa/files/Sources/%{version}%20%28stable%29/%{name}-%{version}-%{reltype}-src.tar.gz.asc
Source2:	privoxy.logrotate
Source4:	%{name}.service
Patch0:		privoxy-3.0.21-mga-mdv-missing-user.filter.patch
# (cjw) add a "address-family-preference" option that allows disabling IPv6 DNS lookups,
#       forcing outgoing HTTP requests to be IPv4
Patch1:		privoxy-3.0.29-mga-address-family-preference.patch
# (cjw) from debian: don't translate documentation to locale-dependent 8-bit ascii
Patch2:		privoxy-3.0.21-mga-deb-8bit_manual.patch
# (cjw) documentation and default configuration changes and cleanups for mageia
Patch3:		privoxy-3.0.21-mga-mageia-specific-config.patch
Requires(post): rpm-helper
Requires(preun): rpm-helper
Provides:	junkbuster = %{version}-%{release}
Provides:	webproxy
BuildRequires:	man
BuildRequires:	pkgconfig(libpcre2-8)
BuildRequires:	pkgconfig(zlib)
# for manual
BuildRequires:	openjade
BuildRequires:	docbook-dtds
BuildRequires:	docbook-style-dsssl
BuildRequires:	w3m

%description
Privoxy is a web proxy with advanced filtering capabilities for protecting
privacy, filtering web page content, managing cookies, controlling access, and
removing ads, banners, pop-ups and other obnoxious Internet Junk. Privoxy has a
very flexible configuration and can be customized to suit individual needs and
tastes. Privoxy has application for both stand-alone systems and multi-user
networks.

Privoxy was previously called Internet Junkbuster.

To configure privoxy, go to http://config.privoxy.org/

Privoxy proxy is running on port 8118

%prep

%setup -n %{name}-%{version}-%{reltype} -q

%autopatch -p1

%build
#needed for build
autoreconf -fi

%serverbuild
%configure --with-user=daemon --with-group=daemon
%make_build
make dok
make config-file

#remove backup files
rm -f doc/webserver/user-manual/*.bak

%install
mkdir -p %{buildroot}%{_sbindir} \
         %{buildroot}%{_mandir}/man8 \
         %{buildroot}/var/log/privoxy \
         %{buildroot}%{privoxyconf}/templates \
         %{buildroot}%{_sysconfdir}/logrotate.d

install -m 755 privoxy %{buildroot}%{_sbindir}/privoxy
install -m 644 privoxy.8 %{buildroot}%{_mandir}/man8/privoxy.8

# Install various config files
for i in *.action default.filter trust; do
	install -m 644 $i %{buildroot}%{privoxyconf}/
done
for i in templates/*; do
	install -m 644 $i %{buildroot}%{privoxyconf}/templates/
done
install -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 %{SOURCE4} %{buildroot}%{_unitdir}/%{name}.service

# verify all file locations, etc. in the config file
# don't start with ^ or commented lines are not replaced
sed -e 's!^confdir.*!confdir /etc/privoxy!g' \
    -e 's!^logdir.*!logdir /var/log/privoxy!g' \
    < config  > %{buildroot}%{privoxyconf}/config

# create compatibility symlink
ln -s match-all.action %{buildroot}/%{privoxyconf}/standard.action

%triggerin -- msec < 0.17
for i in 0 1 2 3 4 5; do
  permfile="%{_sysconfdir}/security/msec/perm.$i"
  if grep -q '^/var/log/privoxy' $permfile; then
    perl -pi -e 's|^/var/log/privoxy\s.*|/var/log/prixovy\t\t\t\tdaemon.daemon\t700|' $permfile
  else
    echo -e "/var/log/prixovy\t\t\t\tdaemon.daemon\t700" >> $permfile
  fi
done


%post
%_post_service privoxy

%preun
%_preun_service privoxy

%files
%doc AUTHORS ChangeLog README  
%doc doc/webserver
%attr (0700,daemon,daemon) /var/log/privoxy
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_sbindir}/*
%{_mandir}/man8/*

%defattr(664,daemon,daemon,755)
%dir %{privoxyconf}
%config(noreplace) %{privoxyconf}/config
%config            %{privoxyconf}/default.action
%config(noreplace) %{privoxyconf}/default.filter
%config(noreplace) %{privoxyconf}/templates
%config(noreplace) %{privoxyconf}/match-all.action
%config(noreplace) %{privoxyconf}/trust
%config(noreplace) %{privoxyconf}/user.action
%config(noreplace) %{privoxyconf}/regression-tests.action
%{privoxyconf}/standard.action
%{_unitdir}/%{name}.service


%changelog
* Mon May 26 2025 ns80 <ns80> 4.0.0-1.mga10
+ Revision: 2186464
- new version 4.0.0
- drop pcre2 patches

* Sat Oct 28 2023 daviddavid <daviddavid> 3.0.34-2.mga10
+ Revision: 2002236
- add debian patches to switch to pcre2

* Mon Feb 06 2023 luigiwalser <luigiwalser> 3.0.34-1.mga9
+ Revision: 1938757
- 3.0.34

* Mon Mar 28 2022 umeabot <umeabot> 3.0.33-2.mga9
+ Revision: 1830550
- Mageia 9 Mass Rebuild

* Wed Dec 08 2021 luigiwalser <luigiwalser> 3.0.33-1.mga9
+ Revision: 1761194
- 3.0.33
- rediff patch 2
- remove unnecessary hunks of patch 3

* Sun Oct 17 2021 cjw <cjw> 3.0.32-2.mga9
+ Revision: 1752019
- use reload instead of restart in logrotate config

* Sun Feb 28 2021 neoclust <neoclust> 3.0.32-1.mga9
+ Revision: 1694487
- New version 3.0.32 (mga#28456)

* Wed Feb 03 2021 neoclust <neoclust> 3.0.31-2.mga8
+ Revision: 1674686
- Rebuild with fixed manpages

* Wed Feb 03 2021 neoclust <neoclust> 3.0.31-1.mga8
+ Revision: 1674678
- Fix file list
- New security version (mga#28281)

* Sun Nov 29 2020 kekepower <kekepower> 3.0.29-1.mga8
+ Revision: 1650138
- Update to version 3.0.29
- Rediff Patch1

* Wed Aug 12 2020 ovitters <ovitters> 3.0.28-3.mga8
+ Revision: 1613635
- service file: fix unit after/wants to network-online.target (per Fedora), plus remove syslog for stderr/stdout (mga#27093)

* Fri Feb 14 2020 umeabot <umeabot> 3.0.28-2.mga8
+ Revision: 1521751
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Dec 31 2018 kekepower <kekepower> 3.0.28-1.mga7
+ Revision: 1347467
- Update to version 3.0.28
- Rediffed patches 1, 2 and 3

* Sun Sep 23 2018 umeabot <umeabot> 3.0.26-2.mga7
+ Revision: 1300378
- Mageia 7 Mass Rebuild

* Sun Oct 01 2017 cjw <cjw> 3.0.26-1.mga7
+ Revision: 1162080
- 3.0.26

* Thu Jan 28 2016 cjw <cjw> 3.0.24-1.mga6
+ Revision: 928359
- 3.0.24

* Mon Jan 26 2015 cjw <cjw> 3.0.23-1.mga5
+ Revision: 812362
- 3.0.23

* Sun Dec 28 2014 cjw <cjw> 3.0.22-1.mga5
+ Revision: 806998
- re-add patch1 as sent upstream (but config syntax may still change)
- patch4: fix doc build
+ solbu <solbu>
- Rename patches, according to policy
- Drop P1. Merged upstream
- New version

* Sun Oct 26 2014 cjw <cjw> 3.0.21-8.mga5
+ Revision: 793535
- patch2: from debian: do not generate high-ascii characters from sgml files
- patch3: mageia specific changes: make user manual available in web interface
- drop unneeded lynx build dependency
- fix removal of backup files in doc dir

* Sun Oct 26 2014 cjw <cjw> 3.0.21-7.mga5
+ Revision: 793357
- add documentation for the unofficial force-ipv4 config option

* Sat Oct 25 2014 cjw <cjw> 3.0.21-6.mga5
+ Revision: 793290
- patch1: add a "force-ipv4" boolean option to disable outgoing ipv6 requests

* Sat Oct 25 2014 cjw <cjw> 3.0.21-5.mga5
+ Revision: 793229
- restart the daemon on logrotate to make sure the old log file is closed
- add ExecReload to systemd service file

* Wed Oct 15 2014 umeabot <umeabot> 3.0.21-4.mga5
+ Revision: 744986
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.0.21-3.mga5
+ Revision: 687786
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 3.0.21-2.mga4
+ Revision: 522506
- Mageia 4 Mass Rebuild

* Tue Mar 12 2013 solbu <solbu> 3.0.21-1.mga3
+ Revision: 402171
- New version
- Rediff patch, and rename according to policy

* Fri Feb 08 2013 solbu <solbu> 3.0.19-4.mga3
+ Revision: 395301
- systemd integration
- Kill init script
- Fix License tag

* Sun Jan 13 2013 umeabot <umeabot> 3.0.19-3.mga3
+ Revision: 378216
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 01 2012 fwang <fwang> 3.0.19-2.mga3
+ Revision: 323740
- br pcreposix

* Wed Mar 07 2012 boklm <boklm> 3.0.19-1.mga2
+ Revision: 221204
- Version 3.0.19

* Wed Nov 23 2011 fwang <fwang> 3.0.18-1.mga2
+ Revision: 171273
- new version 3.0.18

* Wed Sep 07 2011 tv <tv> 3.0.17-1.mga2
+ Revision: 140084
- fix missing LSB keywords
- new release
- BR zlib
- patch : missing user.filter file (mdv#63573)

* Sun Mar 06 2011 ennael <ennael> 3.0.16-2.mga1
+ Revision: 65639
- imported package privoxy


* Tue Dec 07 2010 Oden Eriksson <oeriksson@mandriva.com> 3.0.16-2mdv2011.0
+ Revision: 614612
- the mass rebuild of 2010.1 packages

* Mon May 10 2010 Frederic Crozat <fcrozat@mandriva.com> 3.0.16-1mdv2010.1
+ Revision: 544312
- Release 3.0.16 (stable)

* Wed Oct 21 2009 Frederic Crozat <fcrozat@mandriva.com> 3.0.15-1mdv2010.0
+ Revision: 458511
- Fix buildrequires
- Release 3.0.15
- Replace patches 1 & 4 by source 1 & 2
- Fix buildrequires

* Mon Jul 27 2009 Frederic Crozat <fcrozat@mandriva.com> 3.0.14-1mdv2010.0
+ Revision: 400620
- Release 3.0.14 (beta)
- remove patches 7 (no longer needed) 8, (merged upstream)

* Mon Jun 15 2009 Frederic Crozat <fcrozat@mandriva.com> 3.0.13-1mdv2010.0
+ Revision: 386048
- Release 3.0.13 (beta), with IPv6 support
- do no package backup doc files (Mdv bug #37689)

* Thu Apr 16 2009 Frederic Crozat <fcrozat@mandriva.com> 3.0.12-2mdv2009.1
+ Revision: 367771
- Fix upgrade from previous release if /etc/privoxy/config was modified

* Mon Mar 23 2009 Frederic Crozat <fcrozat@mandriva.com> 3.0.12-1mdv2009.1
+ Revision: 360616
- Release 3.0.12
- Regenerate patch7
- Patch8: fix typo in xml doc

* Mon Mar 16 2009 Frederic Crozat <fcrozat@mandriva.com> 3.0.11-1mdv2009.1
+ Revision: 355925
- Release 3.0.11

* Thu Aug 21 2008 Frederic Crozat <fcrozat@mandriva.com> 3.0.10-1mdv2009.0
+ Revision: 274675
- add missing signature file
- Release 3.0.10
- Remove patch5 (obsolete)

* Fri Aug 01 2008 Thierry Vignaud <tv@mandriva.org> 3.0.8-5mdv2009.0
+ Revision: 259295
- rebuild

* Thu Jul 24 2008 Thierry Vignaud <tv@mandriva.org> 3.0.8-4mdv2009.0
+ Revision: 247222
- rebuild

* Mon Feb 18 2008 Oden Eriksson <oeriksson@mandriva.com> 3.0.8-2mdv2008.1
+ Revision: 171431
- add a virtal provides of webproxy

* Mon Jan 21 2008 Frederic Crozat <fcrozat@mandriva.com> 3.0.8-1mdv2008.1
+ Revision: 155687
- Release 3.0.8
- Remove patches 0 (replace by sed magic), 6 (merged upstream)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Sep 18 2007 Frederic Crozat <fcrozat@mandriva.com> 3.0.6-2mdv2008.0
+ Revision: 89689
- Patch6 (CVS): many filter fixes from CVS
- Patch7: fix Google Reader filter


* Wed Mar 07 2007 Frederic Crozat <fcrozat@mandriva.com> 3.0.6-1mdv2007.1
+ Revision: 134608
- Release 3.0.6
- Bunzip patches
- Remove patches 2, 3 (merged upstream)
- Patch5: fix documentation generation
- Regenerate patch1
- Import privoxy

* Thu May 04 2006 Frederic Crozat <fcrozat@mandriva.com> 3.0.3-11mdk
- Update patch2 to not break Google Finance either

* Thu Feb 09 2006 Frederic Crozat <fcrozat@mandriva.com> 3.0.3-10mdk
- Update patch2 to not break gmail by default

* Mon Jan 09 2006 Olivier Blin <oblin@mandriva.com> 3.0.3-9mdk
- don't forget the LSB patch

* Mon Jan 09 2006 Olivier Blin <oblin@mandriva.com> 3.0.3-8mdk
- convert parallel init to LSB

* Tue Jan 03 2006 Frederic Crozat <fcrozat@mandriva.com> 3.0.3-7mdk
- Fix prereq
- use mkrel
- Patch4: add support for parallel initscript

* Mon Jan 10 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 3.0.3-6mdk 
- Patch3 : fix ie-exploit filter to not be triggered by Amazon

* Sat Jul 24 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 3.0.3-5mdk
- Fix perms on privoxy config directory

* Thu Jul 22 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 3.0.3-4mdk
- Fix default perms/owner of configuration file, otherwise privoxy won't
  be able to modify its config files from web interface.

